pub struct MakeTickersOptions { /* private fields */ }
Options for making a service to subscribe tickers.

Implementations

source

impl MakeTickersOptions

source

pub fn prefer_trade_bid_ask(self, flag: bool) -> Self

Set whether to prefer use ticker from trade bid/ask. Default is false.

source

pub fn first_trade(self, mode: FirstTrade) -> Self

Set how to get the first trade. Default is FirstTrade::Wait. Only works when MakeTickersOptions::prefer_trade_bid_ask is true.

source

pub fn is_prefer_trade_bid_ask(&self) -> bool

Get whether to prefer use ticker from trade bid/ask.

source

pub fn get_first_trade(&self) -> FirstTrade

Get how to get the first trade.

source

pub fn accept_bid_ask_ts(self, flag: bool) -> Self

Accept bid/ask ts. Default is false. Only works when MakeTickersOptions::prefer_trade_bid_ask is true.

source

pub fn is_accept_bid_ask_ts(&self) -> bool

Get whether to accept bid/ask ts.